pcsv

package
v0.15.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2024 License: GPL-3.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ActivitiesToCSV

func ActivitiesToCSV(activities []*activity.Activity, w io.Writer) (err error)

ActivitiesToCSV converts a slice of activities to csv format.

func CSVToActivities added in v0.0.4

func CSVToActivities(reader io.Reader) (activities []*activity.Activity, err error)

CSVToActivities converts csv format to a slice of activities.

func ExportToDb

func ExportToDb(sqldb *db.DB, reader io.Reader, duplicateInsertPolicy db.DuplicateInsertPolicy) (err error)

ExportToDb populates the database with activities in csv format.

Types

This section is empty.

Jump to